.resource-example .v-toolbar{cursor:pointer}pre{background:#f4f4f4;border:1px solid #ddd;border-left:3px solid #f36d33;color:#666;page-break-inside:avoid;font-family:monospace;font-size:12px;line-height:1.6;margin-bottom:1.6em;max-width:100%;overflow:auto;padding:1em 1.5em;display:block;word-wrap:break-word}h1 a{display:inline-block}h1 a i.material-icons{vertical-align:middle;display:none}h1:hover a i.material-icons{display:inline-block;width:30px}.theme--light.v-table tbody tr:hover:not(.v-datatable__expand-row){background:initial}.home{margin-top:6px;margin-bottom:500px}